#safe_radix32

##0.3.0
- Improved TypeError consistency between implementations
- Fixed default imports of the cython build

##0.2.0
- Added fixed-width version of encode
- Minor improvements

##0.1.1
- Fixed a performance issue in the cython impl

##0.1.0
- Initial release
